\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{sharifthesis}[2007/10/19 v1.0]

\LoadClass[12pt,parskip=half-,headsepline,bibliography=totoc,oneside,final]{scrbook}
\DeclareOption{MsThesis}{\AtEndOfPackage{\def\per@fordegree{پایان‌نامه کارشناسی ارشد}\def\lat@fordegree{Ms Thesis}}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrbook}}
\ProcessOptions

\RequirePackage{forloop,amsmath,amsthm,graphicx}

%حاشیه در اینجا مشخص می‌شود.
\RequirePackage[top=3cm, bottom=2.5cm, left=2.5cm, right=3cm]{geometry}
\newcommand\swapmargs{\geometry{left=3cm,right=2.5cm}}

\renewcommand\headfont{\small\slshape}
\parindent1em
\sloppy %\flushbottom %\frenchspacing

\def\blsfactorfront{1.2}
\def\blsfactormain{1.2}
%در ابتدا بایستی فراخوانی شود
\def\START{
	\newdimen\origbls \setlength\origbls\baselineskip
	\let\latinmaketitle\maketitle
	\usepackage{xepersian} \FONTS
	\def\partname{قسمت} \def\bibname{مراجع} \renewcommand\@SepMark{\hskip0pt-}
	\renewcommand\theequation{\thechapter\hskip0pt.\@arabic\c@equation}
	\renewcommand\the@thm@{\thechapter\hskip0pt.\@arabic\c@@thm@}
	\begin{document}
	\frontmatter\pagenumbering{tartibi}
	\baselineskip\blsfactorfront\baselineskip
	\definetitleprops\maketitle\makecanon\makeacknowledge\makeabstract
	{\pagestyle{plain}\tableofcontents\listoffigures\listoftables}
	\baselineskip\blsfactormain\baselineskip
	\ifdefined\@ppreface\chapter*{پیش‌گفتار}\@ppreface\fi
	\mainmatter
	%\renewcommand\jot{.25\baselineskip}
	\abovedisplayskip.5\abovedisplayskip \belowdisplayskip\abovedisplayskip}
%در انتها بایستی فراخوانی شود
\def\FINISH{
	\cleardoubleemptypage\pagestyle{plain}\baselineskip\origbls \BIBLIO
	\backmatter\@lattrue\definetitleprops\swapmargs\begin{latin}\makeabstract\latinmaketitle\end{latin}
	\end{document}}
%صفحات چکیده و قدردانی
\def\makeabstract{
	\cleardoubleemptypage\thispagestyle{empty}\begin{center}\Large\bfseries\@ptitle\end{center}
	\subsection*{\@abstname}{\@pabstract} \paragraph*{\@keywordname:}{\@pkeywds.}}
\def\makeacknowledge{
	\ifdefined\@packnow\cleardoubleemptypage\thispagestyle{empty}\centerline{\Large\bfseries قدردانی}
	\subsection*{}{\@packnow}\fi}
%صفحه تصویب
\def\BSkp{\par\vskip3\bigskipamount} \def\SSkp{\par\vskip\bigskipamount}
\def\signat{امضاء: . . . . . . . . . . .\\[1cm]}
\def\makecanon{
	\cleardoubleemptypage\thispagestyle{empty}
	\begin{center}\large\bfseries به نام او \SSkp\@univ\par\smallskip\@pdepart\end{center}
	\BSkp{\large\@fordegree}\SSkp
	\begin{tabular}{rr} عنوان: & {\large\@ptitle} \\[\medskipamount] \@by: & {\large\@pauthor} \end{tabular}
	\BSkp{\large کمیته ممتحنین}\SSkp
	\begin{center}\begin{tabular*}{.9\textwidth}{r r @{\extracolsep{\fill}} l}
		\@undersup: & {\large\@psupervisor} & \signat
		\ifdefined\@pconsult\@undercons: & {\large\@pconsult} & \signat\fi
		\newcounter{tmp@}
		\forLoop{1}{\value{examin@}}{tmp@}{%
			\csname @@cexamtitle@@\the\c@tmp@\endcsname:
			& {\large \csname @@cexamname@@\the\c@tmp@\endcsname} & \signat}
&& تاریخ: . . . . . . . . .
	\end{tabular*}\end{center}}

%آدرس‌دهی و برچسب‌گذاری معادلات و شکل‌ها
\newcommand \@table@label[1] {table:#1}
\newcommand \@fig@label[1] {fig:#1}
\newcommand \@eqn@label[1] {eqn:#1}
\newcommand \tablelabel[1] {\label{\@table@label#1}}
\newcommand \figlabel[1] {\label{\@fig@label#1}}
\newcommand \eqnlabel[1] {\label{\@eqn@label#1}}
%استیل‌های قضیه و ارجاع به آنها
\newtheorem{@thm@}{}[chapter]
\newcounter{refthm@} \newcounter{thms@}
\newcommand \newtheo[2]{
	\addtocounter{thms@}{1} \newtheorem{#1}[@thm@]{#2}
	\expandafter\def\csname @@cntr@@\the\c@thms@\endcsname{#1}
	\expandafter\def\csname @@cntrname@@\the\c@thms@\endcsname{#2}}
\newenvironment{theo}[3][]%
	{\def\@thm@name{#2}\begin{\@thm@name}[#1]\ifx#3\@empty\else\label{\@thm@name:#3}\fi}%
	{\end{\@thm@name}}
\newtheo{thm}{قضیه} \newtheo{dfn}{تعریف} \newtheo{ntn}{قرارداد} \newtheo{prp}{گزاره} \newtheo{lem}{لم} \newtheo{rem}{تذکر} \newtheo{cor}{نتیجه} \newtheo{exm}{مثال}
%ابزارهای کمکی نگارش ریاضی
\def\m#1{\hskip 1pt minus 1pt\hbox{$#1$}}
%\newcommand\m[1]{\mbox{$#1$}}
\newcommand\Equation[2][\@empty]{\ifx#1\@empty\begin{align*}#2\end{align*}\else\begin{align}\eqnlabel{#1}#2\end{align}\fi}
\newcommand\SplitEquation[2][\@empty] {\Equation[#1]{\begin{split}#2\end{split}}}
%بقیه ابزارها
\def\لاتین#1{\lr{#1}}
\def\گیومه#1{\prq#1\plq}
\def\پانویس#1{\LTRfootnote{ #1}}
\def\سند#1{\cite{#1}}
\def\عطف#1{%
	\ifcsname r@\@eqn@label#1\endcsname\hbox{\eqref{\@eqn@label#1}}%
	\else\forLoop{1}{\value{thms@}}{refthm@}{%
		\def\@THTH{\csname @@cntr@@\the\c@refthm@\endcsname}%
		\ifcsname r@\@THTH:#1\endcsname%
		\csname @@cntrname@@\the\c@refthm@\endcsname\space\hbox{\ref{\@THTH:#1}}%
		\setcounter{refthm@}{999}\fi%
	}\ifnum \c@refthm@>\c@thms@%
	\else\ifcsname r@\@fig@label#1\endcsname%
		\figurename\space\hbox{\ref{\@fig@label#1}}%
	\else\ifcsname r@\@table@label#1\endcsname%
		\tablename\space\hbox{\ref{\@table@label#1}}%
	\else\hbox{\ref{#1}}%
	\fi\fi\fi\fi}

%مشخصات پایان‌نامه به فارسی و لاتین
\newif\if@lat
\newcommand\Author[2] {\def\@pauthor{\if@lat#2\else#1\fi}}
\newcommand\Title[2] {\def\@ptitle{\if@lat#2\else#1\fi}}
\newcommand\Depart[2] {\def\@pdepart{\if@lat#2\else#1\fi}}
\newcommand\Degree[2] {\def\@pdegree{\if@lat#2\else#1\fi}}
\newcommand\Supervisor[2] {\def\@psupervisor{\if@lat#2\else#1\fi}}
\newcommand\Consult[2] {\def\@pconsult{\if@lat#2\else#1\fi}}
\newcommand\Abstract[2] {\def\@pabstract{\if@lat#2\else#1\fi}}
\newcommand\Keywords[2] {\def\@pkeywds{\if@lat#2\else#1\fi}}
\newcommand\Acknowledge[1] {\def\@packnow{#1}}
\newcommand\Preface[1] {\def\@ppreface{#1}}
\newcounter{examin@}
\newcommand\ممتحن[2]{
	\addtocounter{examin@}{1}
	\expandafter\def\csname @@cexamtitle@@\the\c@examin@\endcsname{#1}
	\expandafter\def\csname @@cexamname@@\the\c@examin@\endcsname{#2}}


\def\per@fordegree{پایان‌نامه دکتری}
\def\lat@fordegree{PhD Thesis}

\def\definetitleprops{
  \def\@titlehead{\centering\includegraphics{logo}\par\smallskip{\large\@univ\par\smallskip\@pdepart}}
  \def\@subject{\@fordegree\\[\smallskipamount]\@pdegree}
  \def\@title{\@ptitle}
  \def\@author{{\normalsize\@by}\\[\smallskipamount]{\@pauthor} \\[3\bigskipamount]%
	{\normalsize\@undersup}\\[\smallskipamount]{\it\@psupervisor}%
	\ifdefined\@pconsult\\[2\bigskipamount]{\normalsize\@undercons}\\[\smallskipamount]{\it\@pconsult}\fi%
	\\[2\bigskipamount]}
  \def\@date{\if@lat\latintoday\else\today\fi}
  \if@lat \def\@univ{Sharif University of Technology} \def\@abstname{Abstract} \def\@keywordname{Keywords} \def\@by{By} \def\@fordegree{\lat@fordegree} \def\@undersup{Supervisor} \def\@undercons{Under consult of}%
  \else \def\@univ{دانشگاه صنعتی شریف} \def\@abstname{چکیده} \def\@keywordname{واژه‌های کلیدی} \def\@by{نگارش} \def\@fordegree{\per@fordegree} \def\@undersup{استاد راهنما} \def\@undercons{استاد مشاور}%
  \fi
}
